"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RTTTLConfig(google.protobuf.message.Message):
    """
    Canned message module configuration.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RINGTONE_FIELD_NUMBER: builtins.int
    ringtone: builtins.str
    """
    Ringtone for PWM Buzzer in RTTTL Format.
    """
    def __init__(
        self,
        *,
        ringtone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ringtone", b"ringtone"]) -> None: ...

global___RTTTLConfig = RTTTLConfig
